@@ -13,7 +13,7 @@
 #' @export
 #' @importFrom stats setNames
 #'
-pipeline_vectorized <- function(...) {
+pipeline_vectorized <- function(...) { # nocov start
   lifecycle::deprecate_stop("2.1.0", what = "pipeline_vectorized()",
                       with = "dq_report2()")
-}
+} # nocov end
