@@ -6,7 +6,7 @@
 #' @return the escaped label
 #' @export
 #'
-prep_link_escape <- function(s, html = FALSE) {
+prep_link_escape <- function(s, html = FALSE) { # TODO: Maybe use URLencode(), but take care: also file names are entered, here
   r <- gsub("*", "X", s, fixed = TRUE)
   r <- gsub("\u00b2", "", r, fixed = TRUE)
   r <- gsub("\u00b3", "", r, fixed = TRUE)
@@ -32,6 +32,9 @@ prep_link_escape <- function(s, html = FALSE) {
   r <- gsub("\u00b0", "", r, fixed = TRUE)
   r <- gsub("?", "Q", r, fixed = TRUE)
   r <- gsub("#", "", r, fixed = TRUE)
+  r <- gsub(")", "", r, fixed = TRUE)
+  r <- gsub("(", "", r, fixed = TRUE)
+  r <- gsub("|", "\uFF5C", r, fixed = TRUE)
   # r <- gsub("[\"/ <>&;°@µ~]", "", r, perl = TRUE)
   gsub("\\s+", "", r, perl = TRUE)
 }
