@@ -4,8 +4,7 @@
 #' Use this function to print results objects of the class
 #' `ReportSummaryTable`.
 #'
-#' @param relative [logical] normalize the values in each column by
-#'                           division by the `N` column.
+#' @param relative deprecated
 #' @param dt [logical] use `DT::datatables`, if installed
 #' @param fillContainer [logical] if `dt` is `TRUE`, control table size,
 #'        see `DT::datatables`.
@@ -22,11 +21,24 @@
 #' @importFrom ggplot2 expansion waiver scale_color_gradientn
 #' @export
 #' @return the printed object
-print.ReportSummaryTable <- function(x, relative, dt = FALSE,
+print.ReportSummaryTable <- function(x, relative = lifecycle::deprecated(),
+                                     dt = FALSE,
                                      fillContainer = FALSE,
                                      displayValues = FALSE,
                                      view = TRUE, ...,
                                      flip_mode = "auto") {
+
+  if (lifecycle::is_present(relative)) {
+    # Signal the deprecation to the user
+    lifecycle::deprecate_warn(
+      "2.5.0",
+      "dataquieR::print.ReportSummaryTable(relative = )")
+  }
+
+  #definition of colscale
+  colscale <- c("#B2182B", "#92C5DE", "#2166AC")
+
+
   empty <-
     (!length(setdiff(colnames(x), c("Variables", "N")))) ||
     (!c("Variables") %in% colnames(x)) ||
@@ -61,18 +73,15 @@ print.ReportSummaryTable <- function(x, relative, dt = FALSE,
     attr(x, "from_ReportSummaryTable") <- TRUE
     return(invisible(x))
   }
-  higher_means <- attr(x, "higher_means")
-  if (is.null(higher_means)) higher_means <- "worse"
-  continuous <- attr(x, "continuous")
-  if (is.null(continuous)) continuous <- TRUE
-  colcode <- attr(x, "colcode")
-  if (is.null(colcode)) {
-    continuous <- TRUE
-  }
-  level_names <- attr(x, "level_names")
 
-  if (missing(relative)) relative <- attr(x, "relative")
-  if (is.null(relative)) relative <- continuous
+  mfm <- missing(flip_mode)
+  if (!mfm) oldfm <- flip_mode
+
+  list2env(util_init_respum_tab(x), envir = environment())
+
+  if (!mfm) flip_mode <- oldfm
+
+  x <- util_validate_report_summary_table(x)
 
   hm <- x
   if (relative) {
@@ -91,17 +100,6 @@ print.ReportSummaryTable <- function(x, relative, dt = FALSE,
   # geom_bar() + theme_minimal() +
   #  theme(axis.text.x = element_text(angle = 90, hjust = 1, vjust = 0.5))
 
-  my_cols <- c("#7f0000", "#b30000", "#d7301f", "#ef6548", "#fc8d59",
-               "#fdbb84", "#fdd49e", "#fee8c8", "#2166AC")
-
-  colscale <- attr(x, "colscale")
-  if (is.null(colscale)) {
-    colscale <- my_cols
-  }
-
-  if (higher_means != "worse")
-    colscale <- rev(colscale)
-
   #p <- util_set_size(p,
   #                   width_em  = length(unique(ctab1$Var2)) + 20,
   #                   height_em = length(unique(ctab1$Var1)) + 5)
@@ -113,12 +111,12 @@ print.ReportSummaryTable <- function(x, relative, dt = FALSE,
       w <- DT::datatable(data.frame())
       if (view) print(w)
       attr(w, "from_ReportSummaryTable") <- TRUE
-      return(w)
+      return(invisible(x))
     } else {
       p <- ggplot()
       if (view) print(p)
       attr(p, "from_ReportSummaryTable") <- TRUE
-      return(p)
+      return(invisible(x))
     }
   }
 
@@ -156,6 +154,7 @@ print.ReportSummaryTable <- function(x, relative, dt = FALSE,
                                             levs_con, levs_acc))
   }
 
+
   if (dt) {
     # https://stackoverflow.com/a/50406895
     util_ensure_suggested("DT", "the option dt = TRUE")
@@ -284,7 +283,7 @@ print.ReportSummaryTable <- function(x, relative, dt = FALSE,
 
     attr(w, "from_ReportSummaryTable") <- TRUE
 
-    return(w)
+    return(invisible(w))
 
     # https://stackoverflow.com/a/46043032
   } else {# https://stackoverflow.com/a/64112567
@@ -296,7 +295,7 @@ print.ReportSummaryTable <- function(x, relative, dt = FALSE,
         y <- "value"
         fill <- "value"
         if (relative) {
-          if (max(tb$value) > 0.1)
+          if (suppressWarnings(max(tb$value, na.rm = TRUE)) > 0.1)
             add_amount <- 0.04
           else
             add_amount <- 0.0004
@@ -311,7 +310,7 @@ print.ReportSummaryTable <- function(x, relative, dt = FALSE,
         y <- "value"
         fill <- "value"
         if (relative) {
-          if (max(tb$value) > 0.1)
+          if (suppressWarnings(max(tb$value, na.rm = TRUE)) > 0.1)
             add_amount <- 0.04
           else
             add_amount <- 0.0004
@@ -343,57 +342,84 @@ print.ReportSummaryTable <- function(x, relative, dt = FALSE,
         hjust <- 0.5
         vjust <- 0
       }
-
-      if (relative) {
-        scale_fill <- scale_fill_gradientn(colors = rev(colscale),
-                             labels = scales::percent)
-        gtlb <- paste0(" ", round(tb$value * 100, digits = 2), "%")
-        texts <-
-          geom_text(label = gtlb,
-                    hjust = hjust, vjust = vjust)
+      tb_copy <- tb
+      tb_copy <- tb_copy[is.finite(tb_copy$value), , drop=FALSE]
+      if (nrow(tb_copy) == 0) {
+        p <- ggplot() +
+          annotate("text", x = 0, y = 0, label = "Empty result.") +
+          theme(
+            axis.line = element_blank(),
+            axis.text.x = element_blank(),
+            axis.text.y = element_blank(),
+            axis.ticks = element_blank(),
+            axis.title.x = element_blank(),
+            axis.title.y = element_blank(),
+            legend.position = "none",
+            panel.background = element_blank(),
+            panel.border = element_blank(),
+            panel.grid.major = element_blank(),
+            panel.grid.minor = element_blank(),
+            plot.background = element_blank()
+          )
+        p <- util_set_size(p)
+        gtlb <- character(0)
       } else {
-        scale_fill <- scale_fill_gradientn(colors = rev(colscale))
-        gtlb <- paste0(" ", round(tb$value, digits = 2))
-        texts <-
-          geom_text(label = gtlb,
-                    hjust = hjust, vjust = vjust)
+        if (relative) {
+          scale_fill <- scale_fill_gradientn(colors = rev(colscale),
+                                             labels = scales::percent)
+          gtlb <- paste0(" ", round(tb_copy$value * 100, digits = 2), "%")
+          texts <-
+            geom_text(label = gtlb,
+                      hjust = hjust, vjust = vjust, size = 3.5)
+        } else {
+          scale_fill <- scale_fill_gradientn(colors = rev(colscale))
+          gtlb <- paste0(" ", round(tb_copy$value, digits = 2))
+          texts <-
+            geom_text(label = gtlb,
+                      hjust = hjust, vjust = vjust, size = 3.5)
+        }
+
+        p <- ggplot(tb_copy, aes(
+          x = .data[[x]], y = .data[[y]],
+          fill = .data[[fill]]
+        )) + geom_bar(stat = "identity", na.rm = TRUE,
+                      colour = "white", linewidth = 0.8) + # https://github.com/tidyverse/ggplot2/issues/5051
+          theme_minimal() +
+          texts +
+          fli +
+          scale_fill +
+          xlab("") +
+          guides(fill = guide_legend(
+            title = ""
+            #   ncol = 1, nrow = length(colcode),
+            #   byrow = TRUE
+          )) +
+          rel_ax +
+          theme(
+            legend.position = "bottom",
+            axis.text.x = element_text(angle = 90, hjust = 0),
+            axis.text.y = element_text(size = 10)
+          ) + xlab("") + ylab("")
       }
 
-      p <- ggplot(tb, aes(
-        x = .data[[x]], y = .data[[y]],
-        fill = .data[[fill]]
-      )) + geom_bar(stat = "identity", na.rm = TRUE,
-                    colour = "white", linewidth = 0.8) + # https://github.com/tidyverse/ggplot2/issues/5051
-        theme_minimal() +
-        texts +
-        fli +
-        scale_fill +
-        xlab("") +
-        guides(fill = guide_legend(
-          title = ""
-        #   ncol = 1, nrow = length(colcode),
-        #   byrow = TRUE
-        )) +
-        rel_ax +
-        theme(
-          legend.position = "bottom",
-          axis.text.x = element_text(angle = 90, hjust = 0),
-          axis.text.y = element_text(size = 10)
-        ) + xlab("") + ylab("")
 
       if (suppressWarnings(util_ensure_suggested("plotly",
                                       goal = "generate interactive plots",
                                       err = FALSE))) {
         attr(p, "py") <- local({
-          py <- plotly::plot_ly(tb,
-                  x = tb[[ifelse(is_flipped, y, x)]],
-                  y = tb[[ifelse(is_flipped, x, y)]],
+          tb_copy <- tb
+          tb_copy <- tb_copy[is.finite(tb_copy$value), , drop=FALSE]
+          py <- plotly::plot_ly(tb_copy,
+                  x = tb_copy[[ifelse(is_flipped, y, x)]],
+                  y = tb_copy[[ifelse(is_flipped, x, y)]],
                   type = 'bar',
-                  marker = list(color = tb[[fill]],
+                  marker = list(color = tb_copy[[fill]],
                                 autocolorscale = FALSE,
                                 colorscale = colscale))
+          gtlb_copy <- gtlb
+          gtlb_copy <- gtlb_copy[is.finite(tb$value)]
           py <- plotly::style(py,
-                              text = gtlb,
+                              text = gtlb_copy,
                               textposition = "auto")
 
           if (relative) {
@@ -441,9 +467,26 @@ print.ReportSummaryTable <- function(x, relative, dt = FALSE,
         })
       }
 
+      if (relative) {
+        fct <- 100
+      } else {
+        fct <- 1
+      }
+
+      attr(p, "sizing_hints") <- list(
+        figure_type_id = "bar_chart",
+        rotated = is_flipped,
+        number_of_bars = ifelse(is.null(nrow(p$data)), 0,  nrow(p$data)),
+        range = (fct * suppressWarnings(max(p$data[[y]], na.rm = TRUE)))-
+          (fct * suppressWarnings(min(p$data[[y]], na.rm = TRUE))),
+        no_char_vars = suppressWarnings(max(nchar(as.character(p$data$Variables)), na.rm = TRUE)),
+        no_char_numbers = suppressWarnings(max(nchar(p$data$value), na.rm = TRUE)) #max no. numbers for tick labels
+      )
+
+
       if (view) print(p)
       attr(p, "from_ReportSummaryTable") <- TRUE
-      return(p)
+      return(invisible(p))
 
     } else {
 
@@ -451,8 +494,17 @@ print.ReportSummaryTable <- function(x, relative, dt = FALSE,
         xlim <- as.character(tb$Variables)
         xlim <- xlim[!duplicated(xlim)]
         ylim <- as.character(tb$variable)
-        xsize <- util_plotly_font_size(ncol(hm) - 1)
-        ysize <- util_plotly_font_size(nrow(hm), space = 150)
+      #  xsize <- util_plotly_font_size(ncol(hm) - 1)
+      #  ysize <- util_plotly_font_size(nrow(hm), space = 150)
+
+      #  if(xsize != ysize){
+       #   min_size <- min(xsize, ysize)
+       #   xsize <- min_size
+       #   ysize <- min_size
+       # }
+        xsize <- 10
+        ysize <- 10
+
         p <- ggplot(tb, aes(x = Variables, y = variable, colour = value, size = value)) +
           geom_point()  + #scale_size_continuous(range = c(-1, 10)) + scale_x_discrete() +# breaks = 50 * seq_len(length(unique(tb$Variables)))) +
           #scale_x_discrete(guide = guide_axis(n.dodge = 5)) +
@@ -462,21 +514,40 @@ print.ReportSummaryTable <- function(x, relative, dt = FALSE,
                y = "") +
           scale_x_discrete(limits = xlim) +
           # (if (nrow(hm) < ncol(hm)) coord_flip()) + # 7x5 standard of rmarkdown, not din a4
-          util_coord_flip(w = nrow(hm), h = ncol(hm)) +
           scale_color_gradientn(colors = rev(colscale)) +
           theme_minimal() +
-          theme(aspect.ratio=5*length(unique(tb$Variables))/7/length(unique(tb$Variables)),
+          theme(#aspect.ratio=5*length(unique(tb$Variables))/7/length(unique(tb$Variables)),
                 axis.text.x = element_text(angle = 35, hjust = 1,
                                            size = xsize),
                 axis.text.y = element_text(size = ysize))
 
+
+        no_char_vars <- max(nchar(as.character(tb$Variables)))
+        no_char_cat <-  max(nchar(as.character(tb$variable)))
+
+
+        fli <- util_coord_flip(p = p, w = nrow(hm), h = ncol(hm))
+        is_flipped <- inherits(fli, "CoordFlip")
+        p <- p + fli
+
         p <- util_set_size(p, 500, 300)
 
         if (view) print(p)
 
         attr(p, "from_ReportSummaryTable") <- TRUE
 
-        return(p)
+        attr(p, "sizing_hints") <- list(
+          figure_type_id = "dot_mat",
+          rotated = is_flipped,
+          number_of_vars = nrow(x),
+          number_of_cat =  ncol(x)-2,
+          no_char_vars = no_char_vars,
+          no_char_cat = no_char_cat
+        )
+
+
+
+        return(invisible(p))
 
       } else {
         tb$value <- as.factor(tb$value)
@@ -509,15 +580,18 @@ print.ReportSummaryTable <- function(x, relative, dt = FALSE,
           )) +
           theme(
             legend.position = "bottom",
-            axis.text.x = element_text(angle = 90, hjust = 0),
+            axis.text.x = element_text(angle = 90, hjust = 0, size = 10),
             axis.text.y = element_text(size = 10)
           )
         if (view) print(p)
 
         attr(p, "from_ReportSummaryTable") <- TRUE
 
-        return(p)
+        return(invisible(x))
       }
     }
   }
 }
+
+#' @exportS3Method knitr::knit_print
+knit_print.ReportSummaryTable <- print.ReportSummaryTable
