@@ -7,13 +7,15 @@
 #' @param grouped_by define the columns of the resulting matrix. It can be either
 #' "call_names", one column per function,  or "indicator_metric", one column per indicator
 #' or both c("call_names", "indicator_metric"). The last combination is the default
+#' @param folder_of_report a named vector with the location of variable and call_names
 #' @return invisible html object
 #' @export
 #'
 print.dataquieR_summary <- function(x, ..., grouped_by =
                                       c("call_names",
                                         "indicator_metric"),
-                                    dont_print = FALSE) {
+                                    dont_print = FALSE,
+                                    folder_of_report = NULL) {
   util_ensure_suggested(pkg = c("htmltools",
                                 "digest", "DT", "rmarkdown",
                                 "markdown"),
@@ -26,7 +28,10 @@ print.dataquieR_summary <- function(x, ..., grouped_by =
   grouped_by <- util_match_arg(grouped_by, several_ok = TRUE)
   grouped_by <- unique(grouped_by)
 
-  y <- util_render_table_dataquieR_summary(x, grouped_by = grouped_by)
+  x <- util_reclassify_dataquieR_summary(x)
+
+  y <- util_render_table_dataquieR_summary(x, grouped_by = grouped_by,
+                                           folder_of_report = folder_of_report)
 
   if (!dont_print) {
     print(y)
