@@ -47,6 +47,16 @@
 #'        [https://datatables.net/extensions/buttons/examples/html5/titleMessage.html](https://datatables.net/extensions/buttons/examples/html5/titleMessage.html)
 #' @param messageBottom  [character] footer for download formats, see
 #'        [https://datatables.net/extensions/buttons/examples/html5/titleMessage.html](https://datatables.net/extensions/buttons/examples/html5/titleMessage.html)
+#' @param col_tags [list] if not `NULL`, a named `list()`, names are names used
+#'                        to name a newly created  column-group hide/show
+#'                        button, elements are column names belonging to each
+#'                        column groups as defined by `colnames`
+#' @param searchBuilder [logical] if `TRUE`, display a `searchBuilder`-Button.
+#' @param init_search [list] object to initialize `searchBuilder`, see [`datatables.net`](https://datatables.net/reference/type/SearchBuilder.Criteria)
+#' @param initial_col_tag [character] `col_tags` entry to activate initially
+#' @param additional_init_args [list] if not missing or `NULL`, arguments passed to `JavaScript`, if `searchBuilder == TRUE`
+#' @param additional_columnDefs [list] additional `columnDefs`, can be missing or `NULL`
+#'
 #' @return the table to be added to an `rmd`/´`html` file as
 #'         [htmlwidgets::htmlwidgets]
 #' @seealso [util_formattable()]
@@ -84,15 +94,22 @@ util_html_table <- function(tb,
                   rotate_for_one_row = FALSE,
                   title = dl_fn,
                   messageTop = NULL,
-                  messageBottom = NULL
+                  messageBottom = NULL,
+                  col_tags = NULL,
+                  searchBuilder = FALSE,
+                  initial_col_tag,
+                  init_search,
+                  additional_init_args,
+                  additional_columnDefs
                   ) { # caveat: the fixed columns filter may not work.
-# TODO: https://datatables.net/forums/discussion/75723/adding-custom-colors-for-cells-in-excel-export line #15 in "//custom button for cashflow excel generation" shows, how to add custom styles, https://datatables.net/extensions/buttons/examples/html5/excelCellShading.html shows, how to conditionally apply those. Use this to enable cell background suiting the HTML version of the table.
 # TODO: add comments (descs) to header cells in excel export
+# TODO: add figures to exports
 
   force(copy_row_names_to_column)
 
   util_ensure_suggested("htmltools", "Generating nice tables")
   util_ensure_suggested("DT", "Generating nice tables")
+  util_ensure_suggested("htmlwidgets", "Generating nice tables")
 
   if (is.null(tb) || nrow(tb) == 0 || ncol(tb) == 0) {
     return()
@@ -111,13 +128,14 @@ util_html_table <- function(tb,
   util_stop_if_not(!(cols_are_indicatormetrics && colnames_aliases2acronyms))
 
   if (missing(meta_data)) {
-    if (isTRUE(getOption('knitr.in.progress'))) {
+    if (isTRUE(getOption('knitr.in.progress')) &&
+        exists("report", envir = knitr::knit_global())) {
       # https://stackoverflow.com/a/33121933
       meta_data <- knitr::knit_global()[["report"]][["meta_data"]]
     }
   }
-
   description <- attr(tb, "description")
+  plain_label <- attr(tb[["Variables"]], "plain_label")
   tb <- as.data.frame.matrix(tb,
                              stringsAsFactors = FALSE)
   attr(tb, "description") <- description
@@ -129,7 +147,8 @@ util_html_table <- function(tb,
   numcols <- prep_datatype_from_data(tb) %in%
     c(DATA_TYPES$INTEGER, DATA_TYPES$FLOAT)
   tb[, numcols] <-
-    vapply(tb[, numcols, drop = FALSE], scales::number,
+    vapply(tb[, numcols, drop = FALSE], util_round_to_decimal_places,
+                                                    # format, # scales::number
            FUN.VALUE = character(nrow(tb)))
 
   if (copy_row_names_to_column) {
@@ -147,64 +166,84 @@ util_html_table <- function(tb,
                            c("Variables", VAR_NAMES))
     Variables <- head(Variables, 1)
 
+    pretty_lb <- prep_get_labels( # TODO: use also translations for other labels
+      resp_vars = tb[[Variables]],
+      item_level = meta_data,
+      label_col = label_col,
+      label_class = "LONG",
+      resp_vars_are_var_names_only = Variables == VAR_NAMES,
+      resp_vars_match_label_col_only = Variables == "Variables"
+    )
+
+    if (is.null(plain_label)) {
+      from <- tb[[Variables]]
+    } else {
+      from <- plain_label
+    }
+
     if (Variables == VAR_NAMES &&
         all(c(VAR_NAMES, label_col) %in% names(meta_data))) {
       tb[[Variables]] <- util_map_labels(
-        tb[[Variables]],
+        from,
         meta_data = meta_data,
         to = label_col,
         from = VAR_NAMES,
-        ifnotfound = tb[[Variables]])
+        ifnotfound = from)
     }
 
     if (VAR_NAMES %in% names(meta_data)) {
       vn <- util_map_labels(
-        tb[[Variables]],
+        from,
         meta_data = meta_data,
         to = VAR_NAMES,
         from = label_col,
-        ifnotfound = tb[[Variables]]
+        ifnotfound = from
       ) } else {
-        vn <- tb[[Variables]]
+        vn <- from
       }
 
     if (LABEL %in% names(meta_data)) {
       lb <- util_map_labels(
-        tb[[Variables]],
+        from,
         meta_data = meta_data,
         to = LABEL,
         from = label_col,
-        ifnotfound = tb[[Variables]]
+        ifnotfound = from
       )} else {
-        lb <- tb[[Variables]]
+        lb <- from
       }
 
     if (LONG_LABEL %in% names(meta_data)) {
       llb <- util_map_labels(
-        tb[[Variables]],
+        from,
         meta_data = meta_data,
         to = LONG_LABEL,
         from = label_col,
-        ifnotfound = tb[[Variables]]
+        ifnotfound = from
       ) } else {
-        llb <- tb[[Variables]]
+        llb <- from
       }
 
-    nice_lb <- tb[[Variables]]
-    if (all(util_empty(nice_lb) == util_empty(llb))) {
-      nice_lb <- llb
-    } else if (all(util_empty(nice_lb) == util_empty(lb))) {
-      nice_lb <- lb
-    }
+    # nice_lb <- tb[[Variables]]
+    # if (all(util_empty(nice_lb) == util_empty(llb))) {
+    #   nice_lb <- llb
+    # } else if (all(util_empty(nice_lb) == util_empty(lb))) {
+    #   nice_lb <- lb
+    # }
+    nice_lb <- pretty_lb
 
-    href <- tb[[Variables]]
+    if (Variables == VAR_NAMES) {
+      href <- tb[[Variables]]
+    } else {
+      href <- from
+    }
 
     if (Variables == VAR_NAMES) {
       data <- vn
-      coltitle <- nice_lb
+      hover_title <- nice_lb
     } else {
       data <- nice_lb
-      coltitle <- vn
+      hover_title <- vn
     }
 
     .filter <- data
@@ -212,13 +251,13 @@ util_html_table <- function(tb,
     if (output_format == "RMD") { # a proxy to detect the old rmd based output engine
       href <- paste0("#", prep_link_escape(href,
                                            html = FALSE))
-      coltitle <- prep_title_escape(coltitle,
+      hover_title <- prep_title_escape(hover_title,
                                  html = FALSE)
       data <- prep_title_escape(data,
                         html = FALSE)
       links <- mapply(
         href = href,
-        title = coltitle,
+        title = hover_title,
         filter = .filter,
         data,
         SIMPLIFY = FALSE,
@@ -228,20 +267,59 @@ util_html_table <- function(tb,
       href <- paste0("VAR_", prep_link_escape(href,
                                               html = TRUE),
                      ".html#",
-                     htmltools::urlEncodePath(as.character(href)))
-      coltitle <- prep_title_escape(coltitle,
-                                 html = TRUE)
-      data <- prep_title_escape(data,
-                                html = TRUE)
+                     htmltools::urlEncodePath(prep_link_escape(as.character(href))))
+      if (!is.null(plain_label)) { # if we have a plain_label attribute, we should consider the entries in the Variables column HTML
+        data <- lapply(tb[["Variables"]], htmltools::HTML)
+        hover_title <- prep_title_escape(plain_label,
+                                         html = TRUE)
+      } else {
+        data <- prep_title_escape(data,
+                                  html = TRUE)
+        hover_title <- prep_title_escape(hover_title,
+                                         html = TRUE)
+      }
       onclick <- sprintf(
-        'if (window.hasOwnProperty("dq_report2") && window.dq_report2 && window.location != "%s") { if (all_ids.all_ids.includes("%s")) { window.location = "%s" } else { window.alert("No result avaialable"); } }',
+        'if (window.hasOwnProperty("dq_report2") && window.dq_report2 && window.location != "%s") { if (all_ids.all_ids.includes("%s")) { window.location = "%s" } else { window.alert("No result available"); } }',
                                            href,
                                            href,
                                            href)
+      # prep_get_labels() or l18n
+      hover_text <- mapply(SIMPLIFY = FALSE,
+                           hover_title = hover_title,
+                           vn = vn,
+                           lb = lb,
+                           llb = llb,
+                           function(hover_title, vn, lb, llb) {
+                             .m <- NULL
+                             try({
+                               .m <- meta_data[meta_data[[VAR_NAMES]] == vn, , FALSE]
+                               .m <- data.frame(fix.empty.names = FALSE,
+                                               check.names = FALSE,
+                                               ` ` = unlist(.m[1, , TRUE]))
+                               .m <- .m[!is.na(.m[[1]]), , FALSE]
+                               .m <- head(.m, 5)
+                               .m <- withr::with_options(list(knitr.kable.NA = ''),
+                                                              htmltools::HTML(
+                                                                knitr::kable(.m,
+                                                                             "html")))
+                             }, silent = TRUE)
+                             htmltools::div(
+                               style = htmltools::css(
+                                 overflow_y = "scroll",
+                                 max_height = "80vh"),
+                               htmltools::h5(hover_title),
+                               htmltools::tags$ul(
+                                 htmltools::tags$li(vn),
+                                 htmltools::tags$li(lb),
+                                 htmltools::tags$li(llb)
+                               ),
+                               .m
+                              )
+                           })
       links <- mapply(
         href = sprintf('javascript:console.log("%s")', href),
         onclick = onclick,
-        title = coltitle,
+        title = hover_text,
         filter = .filter,
         data,
         SIMPLIFY = FALSE,
@@ -255,14 +333,17 @@ util_html_table <- function(tb,
   }
 
 
+  # rotate ----
   if (rotate_for_one_row && nrow(tb) == 1) {   #TODO: maybe the description is lost here
+    is_html_escaped <- (identical(attr(tb, "is_html_escaped"), TRUE))
     tb <- data.frame(Name = base::colnames(tb),
                      Value = unlist(tb[1, , TRUE], recursive = FALSE,
                                     use.names = FALSE),
                      stringsAsFactors = FALSE)
+    attr(tb, "is_html_escaped") <- is_html_escaped
   }
 
-
+  # column attributes ----
   if (missing(colnames)) {
     colnames <- base::colnames(tb)
   }
@@ -355,7 +436,9 @@ util_html_table <- function(tb,
     names(acronyms) <- colnames
   } else if (cols_are_indicatormetrics) {
     # acronyms <- colnames
-    acronyms <- util_translate_indicator_metrics(colnames, short = TRUE)
+    acronyms <- util_translate_indicator_metrics(colnames,
+                                                 short = TRUE,
+                                                 long = FALSE)
   } else {
     acronyms <- colnames
     names(acronyms) <- colnames
@@ -370,6 +453,9 @@ util_html_table <- function(tb,
   if (missing(descs)) {
     if(!is.null(attr(tb, "description"))){
       descs <- attr(tb, "description")
+      descs <- descs[colnames]
+      descs[is.na(descs)] <- ""
+      names(descs) <- colnames
     } else if (cols_are_indicatormetrics) {
       descs <- rep("TODO", length(colnames))
     } else {
@@ -405,33 +491,41 @@ util_html_table <- function(tb,
 
   if (rotate_headers) {
     cssClass <- c("vertDT")
-    cn <-
-      paste0("<div class=\"colheader\" colname=\"",
-             coltitles,
-             "\" title=\"",
-             paste(coltitles, descs, sep = "<br />\n\n"),
-             "\">",
-             vapply(
-               strsplit(
-                 acs,
-                 "", fixed = TRUE),
-               function(letters) {
-                 paste0("<span>",
-                        paste0(letters,
-                               collapse = ""),
-                        "</span>")
-               },
-               FUN.VALUE = character(1)),
-             "</div>")
+    if (searchBuilder) {
+      cn <- paste(coltitles)
+    } else {
+      cn <-
+        paste0("<div class=\"colheader\" colname=\"",
+               coltitles,
+               "\" title=\"",
+               paste(coltitles, descs, sep = "<br />\n\n"),
+               "\">",
+               vapply(
+                 strsplit(
+                   acs,
+                   "", fixed = TRUE),
+                 function(letters) {
+                   paste0("<span>",
+                          paste0(letters,
+                                 collapse = ""),
+                          "</span>")
+                 },
+                 FUN.VALUE = character(1)),
+               "</div>")
+    }
   } else {
     cssClass <- "myDT"
-    cn <- paste0("<span colname=\"",
-                 coltitles,
-                 "\" title=\"",
-                 paste(coltitles, descs, sep = "<br />\n\n"),
-                 "\">",
-                 acs,
-                 "</span>")
+    if (searchBuilder) {
+      cn <- paste(coltitles)
+    } else {
+      cn <- paste0("<span colname=\"",
+                   coltitles,
+                   "\" title=\"",
+                   paste(coltitles, descs, sep = "<br />\n\n"),
+                   "\">",
+                   acs,
+                   "</span>")
+    }
   }
 
   if (!is.null(title)) {
@@ -439,16 +533,42 @@ util_html_table <- function(tb,
   }
   if (!is.null(messageTop)) {
     messageTop <- dQuote(messageTop) # these ugly quotes are needed to prevent cleverly Excel from guessing, a title like "2020-01-01" may be a date to be displayed as its integer representation
+  } else {
+    messageTop <- "-" # TODO: Make messsageTop == null work in JS (ie in ~/git/gitlab/QualityIndicatorFunctions/QualityIndicatorFunctions/inst/report-dt-style/report_dt.js)
   }
   if (!is.null(messageBottom)) {
     messageBottom <- dQuote(messageBottom) # these ugly quotes are needed to prevent cleverly Excel from guessing, a title like "2020-01-01" may be a date to be displayed as its integer representation
   }
 
+  col_tags_filter_buttons <- list()
+  if (!is.null(col_tags)) {
+    for (ct in names(col_tags)) {
+      in_group <- colnames %in% col_tags[[ct]]
+      col_tags_filter_buttons <- c(col_tags_filter_buttons, list(list(
+        extend = 'colvisGroup',
+        text = ct,
+        show = which(in_group) - 1,
+        hide = which(!in_group) - 1,
+        name = ct
+        # text = 'No Col.',
+        # hide = ':visible',
+        # show = ':hidden'
+      )))
+    }
+  }
+
+  messageTop = DT::JS(sprintf('function() { return setMsgTop.call(this, "%s"); }',
+                              gsub('"', '\\"', messageTop, fixed = TRUE)))
+
+  if (!missing(additional_columnDefs) && !is.null(additional_columnDefs) &&
+      is.list(additional_columnDefs)) {
+    columnDefs <- c(columnDefs, additional_columnDefs)
+  }
 
   .options <- list(
     dom = "Bt",
     # dom = "Bltp",
-     buttons = list(
+     buttons = c(list(
 #       list( # TODO: https://stackoverflow.com/a/65830545 but Excel also cannot handle inline images
 #         extend = "collection",
 #         text = "xxx",
@@ -463,14 +583,41 @@ util_html_table <- function(tb,
 #         )
 #       ),
       list(
+        extend = 'colvis',
+        collectionLayout = 'fixed columns',
+        postfixButtons = list('colvisRestore', '<input class="search_curr_colvis_input" onkeyup="search_curr_colvis()"></input>', '<button onclick="search_curr_colvis()">Toggle</button>'),
+        # columns: ':not(.noVis)',
+        columnText = DT::JS("function (dt, idx, title) {
+          return dt.column(idx).header().textContent;
+        }")
+      )),
+      col_tags_filter_buttons,
+      list(
+        list(
         extend = 'copy',
         title = title,
         messageTop = messageTop,
         messageBottom = messageBottom,
         exportOptions = list( orthogonal = 'filter',
+                              rows = DT::JS("rowFilter"),
+                              columns = ':visible',
                               format = list(
+                                body = DT::JS("function (data, row, column, node) {
+                                  r = data + \"\";
+                                  if (r.match(/\"data:image\\//g)) {
+                                    r = \"not supported in clipboard\"
+                                  }
+                                  if (r.match(/<table *>/g)) {
+                                    r = \"not supported in clipboard\"
+                                  }
+                                  r = r.replaceAll(/\\<br *\\/?\\>/g,\"  \");
+                                  return r;
+                                }"),
                                 header = DT::JS("function ( data, columnIdx ) {
-                                  return $(data).attr(\"colname\");
+                                  if ($(data).length > 0)
+                                    return $(data).attr(\"colname\");
+                                  else
+                                    return data;
                                 }")
                               ))
       ),
@@ -480,24 +627,37 @@ util_html_table <- function(tb,
         messageTop = messageTop,
         messageBottom = messageBottom,
         filename = dl_fn,
-        exportOptions = list( orthogonal = 'filter',
+        exportOptions = list( orthogonal = 'display',
+                              rows = DT::JS("rowFilter"),
+                              columns = ':visible',
                               format = list(
+                                body = DT::JS("function (data, row, column, node) {
+                                  r = data + \"\";
+                                  if (r.match(/\"data:image\\//g)) {
+                                    r = \"not yet supported in Excel\"
+                                  }
+                                  if (r.match(/<table *>/g)) {
+                                    r = \"not yet supported in Excel\"
+                                  }
+                                  r = r.replaceAll(/\\<br *\\/?\\>/g,\":\\n \");
+                                  r = $('<div />').append(r).text().trim();
+                                  if (isNumeric(r.replaceAll(/\\s/g, ''))) {
+                                    r = r.replaceAll(/\\s/g, '')
+                                  }
+                                  return r;
+                                }"),
                                 header = DT::JS("function ( data, columnIdx ) {
-                                  return $(data).attr(\"colname\");
+                                  if ($(data).length > 0)
+                                    return $(data).attr(\"colname\");
+                                  else
+                                    return data;
                                 }")
                               )),
-        customize =   # https://datatables.net/forums/discussion/60535/freeze-lock-first-row-in-datatables-excel-export-file to freeze first column and first row
-          # https://datatables.net/reference/button/excelHtml5
-          DT::JS('function (xlsx) {
-            var sheet = xlsx.xl.worksheets["sheet1.xml"];
-
-            var freezePanes =
-              \'<sheetViews><sheetView tabSelected="1" workbookViewId="0"><pane xSplit="1" ySplit="3" topLeftCell="B4" activePane="bottomRight" state="frozen"/></sheetView></sheetViews>\';
-            var current = sheet.children[0].innerHTML;
-            current = freezePanes + current;
-            sheet.children[0].innerHTML = current;
-          }
-        '),
+                              customize =
+                                # https://datatables.net/forums/discussion/60535/freeze-lock-first-row-in-datatables-excel-export-file to freeze first column and first row
+                                # https://datatables.net/reference/button/excelHtml5
+                                DT::JS('customize_excel')
+                              ,
         autoFilter = TRUE
       ),
       list(
@@ -507,9 +667,25 @@ util_html_table <- function(tb,
         messageBottom = messageBottom,
         filename = dl_fn,
         exportOptions = list( orthogonal = 'filter',
+                              rows = DT::JS("rowFilter"),
+                              columns = ':visible',
                               format = list(
+                                body = DT::JS("function (data, row, column, node) {
+                                  r = data + \"\";
+                                  if (r.match(/\"data:image\\//g)) {
+                                    r = \"not supported in csv\"
+                                  }
+                                  if (r.match(/<table *>/g)) {
+                                    r = \"not supported in csv\"
+                                  }
+                                  r = r.replaceAll(/\\<br *\\/?\\>/g,\"\\n\");
+                                  return r;
+                                }"),
                                 header = DT::JS("function ( data, columnIdx ) {
-                                  return $(data).attr(\"colname\");
+                                  if ($(data).length > 0)
+                                    return $(data).attr(\"colname\");
+                                  else
+                                    return data;
                                 }")
                               ))
       ),
@@ -519,12 +695,39 @@ util_html_table <- function(tb,
         messageTop = messageTop,
         messageBottom = messageBottom,
         filename = dl_fn,
-        exportOptions = list( orthogonal = 'filter',
+        orientation = "landscape",
+        # pageSize = "A0",
+        exportOptions = list( orthogonal = 'display',
+                              rows = DT::JS("rowFilter"),
+                              columns = ':visible',
+                              stripNewlines = FALSE,
                               format = list(
+                                body = DT::JS("function (data, row, column, node) {
+                                  r = data + \"\";
+                                  if (r.match(/\"data:image\\//g)) {
+                                    r = \"not yet supported in pdf\"
+                                  }
+                                  if (r.match(/<table *>/g)) {
+                                    r = \"not yet supported in pdf\"
+                                  }
+                                  r = r.replaceAll(/\\<br *\\/?\\>/g,\":\\n\");
+                                  r = $('<div />').append(r).text().trim();
+                                  if (isNumeric(r.replaceAll(/\\s/g, ''))) {
+                                    r = r.replaceAll(/\\s/g, '')
+                                  }
+                                  return r;
+                                }"),
                                 header = DT::JS("function ( data, columnIdx ) {
-                                  return $(data).attr(\"colname\");
+                                  if ($(data).length > 0)
+                                    return $(data).attr(\"colname\");
+                                  else
+                                    return data;
                                 }")
-                              ))
+                              )),
+                              customize =   # https://datatables.net/forums/discussion/60535/freeze-lock-first-row-in-datatables-excel-export-file to freeze first column and first row
+                                # https://datatables.net/reference/button/excelHtml5
+                                DT::JS('customize_pdf')
+
       ),
       list(
         extend = 'print',
@@ -532,15 +735,35 @@ util_html_table <- function(tb,
         messageTop = messageTop,
         messageBottom = messageBottom,
         message = dl_fn,
-        exportOptions = list( orthogonal = 'filter',
+        autoPrint = TRUE,
+        exportOptions = list( orthogonal = 'display',
+                              rows = DT::JS("rowFilter"),
+                              columns = ':visible',
+                              stripHtml = FALSE,
                               format = list(
+                                body = DT::JS("function (data, row, column, node) {
+                                  r = data + \"\";
+                                  if (r.match(/\"data:image\\//g)) {
+//                                    r = \"not supported in print\"
+                                  }
+                                  if (r.match(/<table *>/g)) {
+//                                    r = \"not supported in print\"
+                                  }
+//                                  r = r.replaceAll(/\\<br *\\/?\\>/g,\"\\n\");
+                                  return r;
+                                }"),
                                 header = DT::JS("function ( data, columnIdx ) {
-                                  return $(data).attr(\"colname\");
+                                  if ($(data).length > 0)
+                                    return $(data).attr(\"colname\");
+                                  else
+                                    return data;
                                 }")
                               ))
       )
-    ),
-    columnDefs = columnDefs, # https://github.com/rstudio/DT/issues/29
+    )),
+    # https://github.com/rstudio/DT/issues/29
+    columnDefs = c(list(list(className = 'dt-right', targets="_all")),
+                   columnDefs), #to do: make -only- numbers right aligned
     autoWidth = autoWidth,
     rowCallback = rowCallback,
     autoFill = TRUE,
@@ -552,25 +775,73 @@ util_html_table <- function(tb,
     fixedColumns = list(leftColumns = 1 + tb_rownames) # https://stackoverflow.com/a/51623663
   )
 
+  if (searchBuilder) {
+    .options[["searchBuilder"]] <- TRUE
+    .options[["search"]] <- list(return = TRUE)
+    .options[["dom"]] <- paste0("Q", .options[["dom"]])
+  }
+
+
   .options[names(options)] <- options
 
   if (is_matrix_table) {
     cssClass <- paste(cssClass, "matrixTable", collapse = " ")
   }
 
+  ict <- "null"
+  if (!missing(initial_col_tag)) {
+    ict <- sprintf('"%s"', initial_col_tag)
+  }
+
+  is <- "null"
+  if (searchBuilder && !missing(init_search)) {
+    if (util_ensure_suggested("jsonlite",
+                              goal = "search filter init in tables",
+                              err = FALSE)) {
+      is <- jsonlite::toJSON(init_search, auto_unbox = TRUE)
+    }
+  }
+  aia <- "null"
+  if (searchBuilder && !missing(additional_init_args)) {
+    if (util_ensure_suggested("jsonlite",
+                              goal = "additional init in JS tables",
+                              err = FALSE)) {
+      aia <- jsonlite::toJSON(additional_init_args, auto_unbox = TRUE)
+    }
+  }
+
+  ids <- as.character(floor(runif(2, min = 0, max = .Machine$integer.max)))
+  pref <- vapply(nchar(.Machine$integer.max) - nchar(ids),
+         function(n) { paste0(rep("0", n), collapse = "") },
+         FUN.VALUE = character(1))
+  my_id <- paste0("id", paste0(pref, ids), collapse = "")
+
   # TODO: Add links to table columns/rows not only the cells.
   dtable <- DT::datatable(tb,
+                          elementId = my_id,
+                          callback =
+                            DT::JS(sprintf("return(dataquieRdtCallback({ 'initialColTag': %s, 'initSearch': %s, 'additional_init_args': %s, 'table': table }));", ict, is, aia)),
                           escape = FALSE,
                           class = cssClass,
                           filter = filter,
                           rownames = tb_rownames,
                           extensions = c("FixedColumns", # https://stackoverflow.com/a/51623663
-                                         "Buttons"),
+                                         "Buttons",
+                                         "SearchBuilder"),
                           options = .options,
                           colnames = cn,
                           fillContainer = fillContainer,
                           ...)
 
+  js <- sprintf("if (!window.dtConfig) {
+                  window.dtConfig = {}
+                }
+                window.dtConfig['%s'] = %s;", my_id, aia)
+
+  dtable <- htmlwidgets::prependContent(dtable,
+                                        htmltools::tags$script(
+                                  DT::JS(js)))
+
   jqui <- rmarkdown::html_dependency_jqueryui()
   jqui$stylesheet <- "jquery-ui.min.css"
 
