@@ -1,10 +1,10 @@
-
 #' @keywords internal
 util_parallel_classic <- function(all_calls,
                                   worker,
                                   n_nodes,
                                   progress,
-                                  debug_parallel) {
+                                  debug_parallel,
+                                  my_storr_object) {
   outer_env <- parent.frame()
   # was length(parallel::getDefaultCluster()), but parallelMap doesn't use
   # defaultcluster any more!!
@@ -14,6 +14,8 @@ util_parallel_classic <- function(all_calls,
   task_matrix <- matrix(indices, ncol = n_nodes, nrow = tasks_per_node,
                         byrow = TRUE)
 
+  function_names <- lapply(all_calls, rlang::call_name)
+
   if (getOption("parallelMap.mode") %in% c("BatchJobs", "batchtools")) {
     task_matrix <- matrix(seq_along(all_calls), nrow = 1) # for batch jobs, don't split
   }
@@ -32,13 +34,24 @@ util_parallel_classic <- function(all_calls,
       if (debug_parallel) {
         # TODO: log something about the current chunk
       }
+      acs <- all_calls[slices]
       R.devices::suppressGraphics(
         # don't use any auto graphics device (needed for certain
         # parallelization methods)
-        parallelMap::parallelLapply(impute.error = identity,
-                                    all_calls[slices],
-                                    worker,
-                                    env = outer_env)
+        parallelMap::parallelMap(impute.error = identity,
+                                    setNames(nm = names(acs), seq_along(acs)),
+                                    function_name = function_names[slices],
+                                    fun = function(cl, acs, ...) {
+                                      worker(acs[[cl]], ...)
+                                    },
+                                    more.args = list(
+                                      env = outer_env,
+                                      my_storr_object = my_storr_object,
+                                      acs = acs
+                                    ),
+                                 simplify = FALSE,
+                                 use.names = TRUE,
+                                    nm = names(acs))
       )
     }
   ), recursive = FALSE)
