@@ -1,10 +1,10 @@
 #' @keywords internal
-
 util_parallel_futures <- function(all_calls,
                                   worker,
                                   n_nodes,
                                   progress,
-                                  debug_parallel) {
+                                  debug_parallel,
+                                  my_storr_object) { # nocov start
   util_ensure_suggested("future")
   if (!is.null(parallel::getDefaultCluster())) {
     oplan <- future::plan(list(future::tweak(future::cluster,
@@ -18,11 +18,19 @@ util_parallel_futures <- function(all_calls,
   rp <- lapply(setNames(seq_along(all_calls), nm = names(all_calls)),
            function(i) {
              progress(100 * i/length(all_calls))
-             future::future( # IDEA: Use future_promise: https://rstudio.github.io/promises/articles/future_promise.html
+
+             # covr instrumentation breaks the results, here.
+             # nocov start
+             future::future(seed = TRUE, # IDEA: Use future_promise: https://rstudio.github.io/promises/articles/future_promise.html
                {
-                 worker(all_calls[[i]], env = environment())
+                 worker(all_calls[[i]], env = environment(), nm =
+                          names(all_calls)[[i]],
+                        function_name = rlang::call_name(all_calls[[i]]),
+                        my_storr_object = my_storr_object)
                }
               )
+             # nocov end
+
              #   label = names(all_calls)[[i]],
              #   expr = {
              #       R.devices::suppressGraphics(
@@ -45,4 +53,4 @@ util_parallel_futures <- function(all_calls,
   # }
   # as.list(r)
   r
-}
+} # nocov end
