@@ -10,13 +10,15 @@
 util_table_rotator <- function(tb) {  #TODO: should take care of the description attribute
   util_expect_data_frame(tb)
   if (nrow(tb) == 1) {
-    data.frame(
+    is_html_escaped <- attr(tb, "is_html_escaped")
+    tb[] <- lapply(tb, FUN = as.character)
+    util_attach_attr(data.frame(
       check.names = FALSE,
       fix.empty.names = FALSE,
       row.names = NULL,
       ` ` = colnames(tb),
       ` ` = unlist(tb[1, , drop = TRUE])
-    )
+    ), is_html_escaped = is_html_escaped)
   } else {
     tb
   }
